% read the peaks called by MACS from the excel file
function peak_name = step1_read_MACS_peaks(peakfile, nchr, workdir)

[pathstr, peak_name, ext, versn] = fileparts(peakfile);
outputfile = [workdir, peak_name, '_bound_region.mat'];

chr_list = cell(1, nchr);
for chr_id = 1:nchr	% do not consider the genes inside mitochondra
    if chr_id <= nchr-2
        chr_list{chr_id} = ['chr' num2str(chr_id)];
    elseif chr_id == nchr-1
        chr_list{chr_id} = 'chrX';
    elseif chr_id == nchr
        chr_list{chr_id} = 'chrY';
    end
end

disp('Start to read peak information:');
disp('The tab-delimited bed file should have three, four or six columns with only one header line "Chromosom    Start    End    Summit(relative to Start, Optional)    Pvalue(Optional)    FDR(Optional)"');

fs = fopen(peakfile, 'r');
tline = fgetl(fs);          % read header line;
headcontent = regexp(tline, '\t', 'split');
length(headcontent);
if length(headcontent)==4
    CC = textscan(fs, '%s%f%f%f%*[^\n]', 'headerlines', 0);
elseif length(headcontent)==6
    CC = textscan(fs, '%s%f%f%f%f%f%*[^\n]', 'headerlines', 0);
else
    CC = textscan(fs, '%s%f%f%*[^\n]', 'headerlines', 0);
end
fclose(fs);
    
peak.chr_id = CC{1};
peak.bpstart = CC{2};
peak.bpend = CC{3};

Isel = find(ismember(peak.chr_id, chr_list));           % only use the peaks on regular chromosomes
peak.chr_id = peak.chr_id(Isel);
peak.bpstart = peak.bpstart(Isel);
peak.bpend = peak.bpend(Isel);

if length(headcontent)>=4
    peak.bpsummit = CC{2}+CC{4};
    peak.bpsummit = peak.bpsummit(Isel);
    
    if length(headcontent)>=6
        peak.pvalue = CC{5};
        peak.FDR = CC{6};

        peak.pvalue = peak.pvalue(Isel);
        peak.FDR = peak.FDR(Isel);
    end
else
    peak.bpsummit = round((peak.bpstart+peak.bpend)/2);
end

disp([peak_name ': ' num2str(length(peak.chr_id)) ' peaks']);
save(outputfile, 'peak');




