% divide the peaks identified by 2 sets of ChIP-seq/genomewide array peaks into 3 group like: A_Unique; B_unique and A_B_common; 
function step2_classify_2peak_sets_by_overlap(peak_name_1, peak_name_2, workdir, Nsamp)
extention = 1;                  % extention of peak region to find overlapping peaks 

clear peak;
load([workdir, peak_name_1, '_bound_region.mat']);
peak1 = peak;
npeak1 = length(peak1.chr_id);

clear peak;
load([workdir, peak_name_2, '_bound_region.mat']);
peak2 = peak;
npeak2 = length(peak2.chr_id);

peak1.response = zeros(npeak1, 1);
peak2.response = zeros(npeak2, 1);
chr_id_str = unique(peak1.chr_id);
for i = 1:length(chr_id_str)
    I1 = find(strcmp(peak1.chr_id, chr_id_str{i}));
    bpstart_t1 = peak1.bpstart(I1) - extention;
    bpend_t1 = peak1.bpend(I1) + extention;
    
    I2 = find(strcmp(peak2.chr_id, chr_id_str{i}));
    bpstart_t2 = peak2.bpstart(I2);
    bpend_t2 = peak2.bpend(I2);
        
    for m = 1:length(bpstart_t1)
        idx = find((bpend_t1(m)-bpstart_t2).*(bpend_t2-bpstart_t1(m))>=0);
        if ~isempty(idx)
             peak1.response(I1(m)) = 1;
             peak2.response(I2(idx)) = 1;
        end
    end
end

% find and output A_unique peaks
I1uni = find(~peak1.response);
peak1uni.chr_id = peak1.chr_id(I1uni);
peak1uni.bpstart = peak1.bpstart(I1uni);
peak1uni.bpend = peak1.bpend(I1uni);
peak1uni.bpsummit = peak1.bpsummit(I1uni);
peak = peak1uni;
disp([num2str(length(I1uni)), ' ' peak_name_1 ' unique peaks']);
save([workdir, peak_name_1, '_unique_bound_region.mat'], 'peak');

% find and output B_unique peaks
I2uni = find(~peak2.response);
peak2uni.chr_id = peak2.chr_id(I2uni);
peak2uni.bpstart = peak2.bpstart(I2uni);
peak2uni.bpend = peak2.bpend(I2uni);
peak2uni.bpsummit = peak2.bpsummit(I2uni);
peak = peak2uni;
disp([num2str(length(I2uni)), ' ' peak_name_2 ' unique peaks']);
save([workdir, peak_name_2, '_unique_bound_region.mat'], 'peak');
  
% find and output A_common peaks
I1comm = find(peak1.response);
peak1com.chr_id = peak1.chr_id(I1comm);
peak1com.bpstart = peak1.bpstart(I1comm);
peak1com.bpend = peak1.bpend(I1comm);
peak1com.bpsummit = peak1.bpsummit(I1comm);
peak = peak1com;
disp([num2str(length(I1comm)), ' ' peak_name_1 ' common peaks']);
save([workdir, peak_name_1, '_common_bound_region.mat'], 'peak');

% find and output B_common peaks
I2comm = find(peak2.response);
peak2com.chr_id = peak2.chr_id(I2comm);
peak2com.bpstart = peak2.bpstart(I2comm);
peak2com.bpend = peak2.bpend(I2comm);
peak2com.bpsummit = peak2.bpsummit(I2comm);
peak = peak2com;
disp([num2str(length(I2comm)), ' ' peak_name_2 ' common peaks']);
save([workdir, peak_name_2, '_common_bound_region.mat'], 'peak');

% calculate the fold change relative to random permutations
ovlp_num = sum(peak1.response);
ovlp_num_perm = zeros(1, Nsamp);
for i = 1:length(chr_id_str)
    I1 = find(strcmp(peak1.chr_id, chr_id_str{i}));
    bpstart_t1 = peak1.bpstart(I1);
    bpend_t1 = peak1.bpend(I1);
    bplen_t1 = bpend_t1 - bpstart_t1 + 1;
    region_start = min(bpstart_t1);
    region_end = max(bpend_t1);
    region_len = region_end - region_start;
    
    I2 = find(strcmp(peak2.chr_id, chr_id_str{i}));
    bpstart_t2 = peak2.bpstart(I2);
    bpend_t2 = peak2.bpend(I2);
    
    for ns = 1:Nsamp,
        bpstart_rand = region_start + floor(region_len * rand(length(bpstart_t1),1));
        bpend_rand = bpstart_rand + bplen_t1;
        for m = 1:length(bpstart_t1)
            if ~isempty(find((bpend_rand(m)-bpstart_t2).*(bpend_t2-bpstart_rand(m))>=0, 1))  
                ovlp_num_perm(ns) = ovlp_num_perm(ns) + 1;
            end
        end
    end
end

disp(['In random permutations, overlapping peaks: ', num2str(mean(ovlp_num_perm)), '+/-', num2str(std(ovlp_num_perm))]);
disp(['Fold change: ', num2str(ovlp_num/mean(ovlp_num_perm))]);