function step4_calculate_peak_read_density(peak_name_1, peak_name_2, marker_name_1, marker_name_2, extention, workdir, nchr, tag_shift_1, tag_shift_2, tag_length_1, tag_length_2)
  
rawdatadir = [workdir 'rawdata_chr\'];
marker_list = [ {marker_name_1}, {marker_name_2}];

peak_list = [ {[peak_name_1 '_common']}, ...  
            {[peak_name_2 '_common']}, ...  
            {[peak_name_1 '_unique']}, ...  
            {[peak_name_2 '_unique']}, ...  
            ];
npeakset = length(peak_list);
  
for mkidx = 1:2
	marker_name = marker_list{mkidx}
    if mkidx==1
        tag_shift = tag_shift_1;
        tag_length = tag_length_1;
    else
        tag_shift = tag_shift_2;
        tag_length = tag_length_2;
    end

    for psidx = 1:npeakset
        clear peak;
        TFname = peak_list{psidx}
        datafile = [workdir, TFname, '_bound_region.mat'];
        load(datafile);     % peak nchr = 24;

        chr_list = cell(1, nchr);
        for chr_id = 1:nchr	% do not consider the genes inside mitochondra
            if chr_id <= nchr-2
                chr_list{chr_id} = ['chr' num2str(chr_id)];
            elseif chr_id == nchr-1
                chr_list{chr_id} = 'chrX';
            elseif chr_id == nchr
                chr_list{chr_id} = 'chrY';
            end
        end
        
        Isel = find(ismember(peak.chr_id, chr_list));
        peak.chr_id = peak.chr_id(Isel);
        peak.bpstart = peak.bpstart(Isel);
        peak.bpend = peak.bpend(Isel);
        peak.bpsummit = peak.bpsummit(Isel);

        npeak = length(peak.chr_id);
        peak.read_density = zeros(npeak, 1);
        peak.read_num = 0;
        outfile = [workdir, TFname, '_peaks_', marker_name, '_read_density.mat'];

        %chr_list = unique(peak.chr_id);
        nchr = length(chr_list);
        for chr_id = 1:nchr,
            disp(['reading reads of ' marker_name , ' on ', chr_list{chr_id}, ' for ', TFname, ' peaks']);
            tagfile = [rawdatadir, chr_list{chr_id}, '\', marker_name, '.', chr_list{chr_id}, '.txt'];

            % read chip-seq tags
            fs = fopen(tagfile, 'r');
            CC = textscan(fs, '%*s%f%c');
            fclose(fs);
            nread_chr = length(CC{1}); 
            peak.read_num = peak.read_num + nread_chr;
            %read_position = zeros(1, nread_chr);
            read_position = CC{1} + tag_shift + round(tag_length/2);

            %Iplus = find(CC{2} == '+');
            %read_position(Iplus) = CC{1} + tag_shift + round(tag_length/2);
            Iminus = find(CC{2} == '-');
            read_position(Iminus) = CC{1}(Iminus) - tag_shift + round(tag_length/2);
            clear CC;

            % map to genes
            select_peak = find(strcmp(peak.chr_id, chr_list{chr_id}));
            nselect = length(select_peak);

            for j = 1:nselect,
                peak_idx = select_peak(j);
                peak_summit = peak.bpsummit(peak_idx);

                peak_bpstart = peak_summit - extention;
                peak_bpend = peak_summit + extention;
                peak.read_density(peak_idx) = sum(read_position<peak_bpend & read_position>=peak_bpstart)*1000/(2*extention);
            end
        end
        
        save(outfile, 'peak');
    end
end

