% Note1: Change the parameter values inside the parameter region to run MAnorm on your samples; 
% Note2: All the input files should be of tab-delimited text format.
% Note3: To know the usage of a MATLAB function, type "help function_name", e.g. help addpath, in MATLAB command line. 
clear;
addpath('CodeLib');

%%%%%% start of parameter region %%%%%%
nchr = 24;              % number of chromosomes; 24 for human, 21 for mouse

% the bed file name of peak coordinate of sample 1
peakfile_1 = 'H:\Work\ChIP-seq\MAnorm\CODEpackage\Input\Hela_cMyc_rep1.bed';
% the bed file name of read coordinate of sample 1: Yale ENCODE MYC ChIP-seq data replicate 1 in HelaS3 cells
rawdatafile_1 = 'H:\Data_downloaded\Encode\TF\rawdata_hg18\wgEncodeYaleChIPseqAlignmentsRep1Helas3CmycV2.tagAlign';
% shift size of reads for sample 1; which equal to the half of the DNA fragment after size selection
tag_shift_1 = 100;      
% length of reads for sample 1
tag_length_1 = 36;        

% the bed file name of peak coordinate of sample 2
peakfile_2 = 'H:\Work\ChIP-seq\MAnorm\CODEpackage\Input\K562_cMyc_rep1.bed';
% the bed file name of read coordinate of sample 2: Yale ENCODE MYC ChIP-seq data replicate 1 in K562 cells
rawdatafile_2 = 'H:\Data_downloaded\Encode\TF\rawdata_hg18\Yale_K562_Myc_tagAlign_rep1_FC20GEE_062208_s_7.bed';
% shift size of reads for sample 1; which equal to the half of the DNA fragment after size selection
tag_shift_2 = 100;      
% length of reads for sample 1
tag_length_2 = 36;   

% directory of work folder to store temperary files; should be made before analysis
workdir = 'H:\Work\ChIP-seq\MAnorm\CODEpackage\Data\';
% directory of output folder to store output files; should be made before analysis
outputdir = 'H:\Work\ChIP-seq\MAnorm\CODEpackage\Output\'; 
% name of comparison
MApair = 'cMyc_pair1';

extention = 500;            % 2*extention = the window size to calculate read density; we recommend extention=1000 for histone modification, extention=500 for transcription factor
summit2summit_dist = 250;      % the selected common peaks much have summit-to-summit distance smaller than this value to as matched common peaks; suggest to be half of extention

Mcut_unbiased = 1;          % Curoff of |M| value to define unbiased peaks between 2 samples; here M value is the log2 fold change at peak region between two samples, value 1 means fold change 2
                            % Non-cell type-specific binding regions: all peaks associated with |M|<Mcut_unbiaseda.
                            
Mcut_biased = 1;            % Cutoff of M value cutoff to define biased peaks between 2 samples: 
Pcut_biased = 1e-2;         % Cutoff of P value (of differential binding) cutoff to define biased peaks between 2 samples;
                            % Sample 1-specific binding regions: all peaks associated with M>=Mcut_biased and P<Pcut_biased; 
                            % Sample 2-specific binding regions: all peaks associated with M<=-Mcut_biased and P<Pcut_biased;
%%%%%% end of parameter region %%%%%%

% read peaks;
disp(' ');
disp('Step1: read peaks');
peak_name_1 = step1_read_MACS_peaks(peakfile_1, nchr, workdir);
peak_name_2 = step1_read_MACS_peaks(peakfile_2, nchr, workdir);

% classify common or unique peaks
disp(' ');
disp('Step2: classify common or unique peaks');
Nsamp = 100;                 % number of random permutation to calculate fold enrichment of overlap 
step2_classify_2peak_sets_by_overlap(peak_name_1, peak_name_2, workdir, Nsamp);

% split raw data by chromosome
disp(' ');
disp('Step3: read and split raw data by chromosome');
[pathstr1, marker_name_1, ext1, versn1] = fileparts(rawdatafile_1);
step3_split_sequencing_data_2chr(rawdatafile_1, nchr, workdir);

[pathstr2, marker_name_2, ext2, versn2] = fileparts(rawdatafile_2);
step3_split_sequencing_data_2chr(rawdatafile_2, nchr, workdir);

% calculate read density in peaks
disp(' ');
disp('Step4: calculate read density in peaks');
step4_calculate_peak_read_density(peak_name_1, peak_name_2, marker_name_1, marker_name_2, extention, workdir, nchr, tag_shift_1, tag_shift_2, tag_length_1, tag_length_2);

% calculate normalized M-A values 
disp(' ');
disp('Final Step: normalize and output the M-A values');
step5_rescale_peak_strength_by_common_peaks(peak_name_1, peak_name_2, marker_name_1, marker_name_2, summit2summit_dist, workdir, MApair, outputdir);

% output the normalized M-value to wig file (in order to upload to genome browsers)
disp(' ');
disp('Summarize data: output the M value of 2 peak sets to wig files');
step6_output_peak_Mvalue_2wig_file(peak_name_1, workdir, MApair, outputdir);
step6_output_peak_Mvalue_2wig_file(peak_name_2, workdir, MApair, outputdir);

% merge common peaks and define unbiased and biased peaks between two samples based on given M-value and P-value cutoff 
disp(' ');
disp('Summarize data: merge common peaks and extract differential and non-differential binding regions');
step7_define_biased_unbiased_peaks(peak_name_1, peak_name_2, workdir, MApair, outputdir, Mcut_unbiased, Mcut_biased, Pcut_biased)

% clean up
rmpath('CodeLib');
clear all;